@@ -19,8 +19,8 @@ import logging
 
 
 logger = logging.getLogger(__name__)
-prefix = 'plone.app.querystring'
-INVALID_OPERATION = 'Invalid operation %s for criterion: %s'
+prefix = "plone.app.querystring"
+INVALID_OPERATION = "Invalid operation %s for criterion: %s"
 
 
 # Converters
@@ -28,9 +28,9 @@ class CriterionConverter(object):
 
     # Last part of the code for the dotted operation method,
     # e.g. 'string.contains'.
-    operator_code = ''
+    operator_code = ""
     # alternative code, possibly used if the first code does not work.
-    alt_operator_code = ''
+    alt_operator_code = ""
 
     def get_query_value(self, value, index, criterion):
         # value may contain a query and some parameters, but in the
@@ -39,60 +39,52 @@ class CriterionConverter(object):
 
     def get_operation(self, value, index, criterion):
         # Get dotted operation method.  This may depend on value.
-        return '{0}.operation.{1}'.format(prefix, self.operator_code)
+        return "{0}.operation.{1}".format(prefix, self.operator_code)
 
     def get_alt_operation(self, value, index, criterion):
         # Get dotted operation method.  This may depend on value.
-        return '{0}.operation.{1}'.format(prefix, self.alt_operator_code)
+        return "{0}.operation.{1}".format(prefix, self.alt_operator_code)
 
     def is_index_known(self, registry, index):
         # Is the index registered as criterion index?
-        key = '{0}.field.{1}'.format(prefix, index)
+        key = "{0}.field.{1}".format(prefix, index)
         try:
             registry.get(key)
         except KeyError:
             logger.warn(
-                'Index {0} is no criterion index. Registry gives '
-                'KeyError: {1}. Try inspecting portal_atct...'.format(
-                    index, key
-                )
+                "Index {0} is no criterion index. Registry gives "
+                "KeyError: {1}. Try inspecting portal_atct...".format(index, key)
             )
             try:
                 api.portal.get().portal_atct.getIndex(index)
             except KeyError:
                 logger.error(
-                    'Index {0} is no criterion index. Giveup, sorry.'.format(
-                        index
-                    )
+                    "Index {0} is no criterion index. Giveup, sorry.".format(index)
                 )
                 return False
         return True
 
     def is_index_enabled(self, registry, index):
         # Is the index enabled as criterion index?
-        key = '{0}.field.{1}'.format(prefix, index)
+        key = "{0}.field.{1}".format(prefix, index)
         try:
             index_data = registry.get(key)
-            if index_data.get('enabled'):
+            if index_data.get("enabled"):
                 return True
         except KeyError:
             logger.warn(
-                'Index {0} is no criterion index. Registry gives '
-                'KeyError: {1}. Try inspecting portal_atct...'.format(
-                    index, key
-                )
+                "Index {0} is no criterion index. Registry gives "
+                "KeyError: {1}. Try inspecting portal_atct...".format(index, key)
             )
             try:
                 index_obj = api.portal.get().portal_atct.getIndex(index)
                 return index_obj.enabled
             except KeyError:
                 logger.error(
-                    'Index {0} is no criterion index. Giveup, sorry.'.format(
-                        index
-                    )
+                    "Index {0} is no criterion index. Giveup, sorry.".format(index)
                 )
                 return False
-        logger.warn('Index %s is not enabled as criterion index. ', index)
+        logger.warn("Index %s is not enabled as criterion index. ", index)
         return False
 
     def switch_type_to_portal_type(self, value, criterion):
@@ -102,13 +94,13 @@ class CriterionConverter(object):
         # - portal_type 'Document' has Type 'Page'.
         # - portal_type 'Topic' has Type 'Collection (old)'.
         if isinstance(value, dict):
-            values = value.get('query', [])
+            values = value.get("query", [])
         else:
             values = value
         if not values:
             return value
         new_values = []
-        ttool = getToolByName(criterion, 'portal_types')
+        ttool = getToolByName(criterion, "portal_types")
         type_to_portal_type = {}
         portal_types = ttool.objectIds()
         for portal_type, Type in ttool.listTypeTitles().items():
@@ -119,11 +111,11 @@ class CriterionConverter(object):
                 if Type in portal_types:
                     portal_type = Type
                 else:
-                    logger.warn('Cannot switch Type %r to portal_type.', Type)
+                    logger.warn("Cannot switch Type %r to portal_type.", Type)
                     continue
             new_values.append(portal_type)
         if isinstance(value, dict):
-            value['query'] = new_values
+            value["query"] = new_values
         else:
             value = new_values
         return value
@@ -133,20 +125,20 @@ class CriterionConverter(object):
         # Check that the operation exists.
         op_info = registry.get(operation)
         if op_info is None:
-            logger.error('Operation %r is not defined.', operation)
+            logger.error("Operation %r is not defined.", operation)
             return False
-        op_function_name = op_info.get('operation')
+        op_function_name = op_info.get("operation")
         try:
             resolve(op_function_name)
         except ImportError:
             logger.error(
-                'ImportError for operation %r: %s', operation, op_function_name
+                "ImportError for operation %r: %s", operation, op_function_name
             )
             return False
         return True
 
     def get_valid_operation(self, registry, index, value, criterion):
-        key = '{0}.field.{1}.operations'.format(prefix, index)
+        key = "{0}.field.{1}.operations".format(prefix, index)
         try:
             operations = registry.get(key)
         except KeyError:
@@ -164,21 +156,21 @@ class CriterionConverter(object):
             return operation
 
     def add_to_formquery(self, formquery, index, operation, query_value):
-        row = {'i': index, 'o': operation}
+        row = {"i": index, "o": operation}
         if query_value is not None:
-            row['v'] = query_value
+            row["v"] = query_value
         formquery.append(row)
 
     def __call__(self, formquery, criterion, registry):
         criteria = criterion.getCriteriaItems()
         if not criteria:
-            logger.warn('Ignoring empty criterion %s.', criterion)
+            logger.warn("Ignoring empty criterion %s.", criterion)
             return
         for index, value in criteria:
             # Check if the index is known and enabled as criterion index.
-            if index == 'Type':
+            if index == "Type":
                 # Try to replace Type by portal_type
-                index = 'portal_type'
+                index = "portal_type"
                 value = self.switch_type_to_portal_type(value, criterion)
             # if not self.is_index_known(registry, index):
             #     logger.info('Index %s not known in registry.', index)
@@ -192,13 +184,11 @@ class CriterionConverter(object):
 
             # Get the operation method.
 
-            operation = self.get_valid_operation(
-                registry, index, value, criterion
-            )
+            operation = self.get_valid_operation(registry, index, value, criterion)
             if not operation:
                 logger.warning(INVALID_OPERATION % (operation, criterion))
                 # TODO: raise an Exception?
-                continue
+                operation = "plone.app.querystring.operation.selection.any"
 
             # Get the value that we will query for.
             query_value = self.get_query_value(value, index, criterion)
@@ -231,7 +221,7 @@ class ATDateCriteriaConverter(CriterionConverter):
 
     def __call__(self, formquery, criterion, registry):  # noqa
         if criterion.value is None:
-            logger.warn('Ignoring empty criterion %s.', criterion)
+            logger.warn("Ignoring empty criterion %s.", criterion)
             return
         field = criterion.Field()
         value = criterion.Value()
@@ -242,13 +232,13 @@ class ATDateCriteriaConverter(CriterionConverter):
         self.is_index_enabled(registry, field)
 
         # Negate the value for 'old' days
-        if criterion.getDateRange() == '-':
+        if criterion.getDateRange() == "-":
             value = -value
 
         date = DateTime() + value
 
         # Get the possible operation methods.
-        key = '{0}.field.{1}.operations'.format(prefix, field)
+        key = "{0}.field.{1}.operations".format(prefix, field)
         try:
             operations = registry.get(key)
         except KeyError:
@@ -257,7 +247,7 @@ class ATDateCriteriaConverter(CriterionConverter):
         def add_row(operation, value=None):
             if operation not in operations:
                 logger.warn(
-                    'INVALID_OPERATION {0} for Criterion {1}'.format(
+                    "INVALID_OPERATION {0} for Criterion {1}".format(
                         operation, criterion
                     )
                 )
@@ -266,7 +256,7 @@ class ATDateCriteriaConverter(CriterionConverter):
                 # raise ValueError(INVALID_OPERATION % (operation, criterion))
             if not self.is_operation_valid(registry, operation):
                 logger.warn(
-                    'INVALID_OPERATION {0} for Criterion {1}'.format(
+                    "INVALID_OPERATION {0} for Criterion {1}".format(
                         operation, criterion
                     )
                 )
@@ -274,91 +264,89 @@ class ATDateCriteriaConverter(CriterionConverter):
                 # just ignore it? Commented, must be handled better
                 # raise ValueError(INVALID_OPERATION % (operation, criterion))
             # Add a row to the form query.
-            row = {'i': field, 'o': operation}
+            row = {"i": field, "o": operation}
             if value is not None:
-                row['v'] = value
+                row["v"] = value
             formquery.append(row)
 
         operation = criterion.getOperation()
-        if operation == 'within_day':
+        if operation == "within_day":
             if date.isCurrentDay():
-                new_operation = '{0}.operation.date.today'.format(prefix)
+                new_operation = "{0}.operation.date.today".format(prefix)
                 add_row(new_operation)
                 return
             date_range = (date.earliestTime(), date.latestTime())
-            new_operation = '{0}.operation.date.between'.format(prefix)
+            new_operation = "{0}.operation.date.between".format(prefix)
             add_row(new_operation, date_range)
             return
-        if operation == 'more':
+        if operation == "more":
             if value != 0:
-                new_operation = (
-                    '{0}.operation.date.'
-                    'largerThanRelativeDate'.format(prefix)
+                new_operation = "{0}.operation.date." "largerThanRelativeDate".format(
+                    prefix
                 )
                 add_row(new_operation, value)
                 return
             else:
-                new_operation = '{0}.operation.date.afterToday'.format(prefix)
+                new_operation = "{0}.operation.date.afterToday".format(prefix)
                 add_row(new_operation)
                 return
-        if operation == 'less':
+        if operation == "less":
             if value != 0:
-                new_operation = (
-                    '{0}.operation.date.' 'lessThanRelativeDate'.format(prefix)
+                new_operation = "{0}.operation.date." "lessThanRelativeDate".format(
+                    prefix
                 )
                 add_row(new_operation, value)
                 return
             else:
-                new_operation = '{0}.operation.date.beforeToday'.format(prefix)
+                new_operation = "{0}.operation.date.beforeToday".format(prefix)
                 add_row(new_operation)
                 return
 
 
 class ATSimpleStringCriterionConverter(CriterionConverter):
-    operator_code = 'string.contains'
+    operator_code = "string.contains"
     # review_state could be a string criterion, but should become a selection.
-    alt_operator_code = 'selection.any'
+    alt_operator_code = "selection.any"
 
 
 class ATCurrentAuthorCriterionConverter(CriterionConverter):
-    operator_code = 'string.currentUser'
+    operator_code = "string.currentUser"
 
 
 class ATSelectionCriterionConverter(CriterionConverter):
-    operator_code = 'selection.any'
-    alt_operator_code = 'selection.is'
+    operator_code = "selection.any"
+    alt_operator_code = "selection.is"
 
     def get_operation(self, value, index, criterion):
         # Get dotted operation method.  This may depend on value.
-        if index == 'Subject':
-            if value['operator'] == 'and':
+        if index == "Subject":
+            if value["operator"] == "and":
                 # Subject is currently the only index that supports
                 # this, because for others it makes no sense.  See
                 # allowed operations in registry.xml in
                 # plone.app.querystring.
-                suffix = 'all'
+                suffix = "all"
             else:
-                suffix = 'any'
-            return '{0}.operation.selection.{1}'.format(prefix, suffix)
+                suffix = "any"
+            return "{0}.operation.selection.{1}".format(prefix, suffix)
         else:
-            return '{0}.operation.{1}'.format(prefix, self.operator_code)
+            return "{0}.operation.{1}".format(prefix, self.operator_code)
 
     def get_query_value(self, value, index, criterion):
-        values = value['query']
+        values = value["query"]
         if (
-            value.get('operator') == 'and'
+            value.get("operator") == "and"
             and len(values) > 1  # noqa
-            and index != 'Subject'  # noqa
+            and index != "Subject"  # noqa
         ):
             logger.warn(
-                "Cannot handle selection operator 'and'. Using 'or'. " "%r",
-                value,
+                "Cannot handle selection operator 'and'. Using 'or'. " "%r", value
             )
 
         # Special handling for portal_type=Topic.
-        if index == 'portal_type' and 'Topic' in values:
+        if index == "portal_type" and "Topic" in values:
             values = list(values)
-            values[values.index('Topic')] = 'Collection'
+            values[values.index("Topic")] = "Collection"
             values = tuple(values)
         return values
 
@@ -371,11 +359,11 @@ class ATReferenceCriterionConverter(ATSelectionCriterionConverter):
     # Note: the new criterion is disabled by default.  Also, it
     # needs the _referenceIs function in the plone.app.querystring
     # queryparser and that function is not defined.
-    operator_code = 'reference.is'
+    operator_code = "reference.is"
 
 
 class ATPathCriterionConverter(CriterionConverter):
-    operator_code = 'string.path'
+    operator_code = "string.path"
 
     def get_query_value(self, value, index, criterion):
         raw = criterion.getRawValue()
@@ -386,7 +374,7 @@ class ATPathCriterionConverter(CriterionConverter):
         # possible values for depth are -1 and 1.
         if not criterion.Recurse():
             for index, path in enumerate(raw):
-                raw[index] = path + '::1'
+                raw[index] = path + "::1"
         else:
             raw = (
                 map(lambda x: api.content.get(UID=x).absolute_url_path(), raw)
@@ -399,7 +387,7 @@ class ATPathCriterionConverter(CriterionConverter):
         if query_value is None:
             return
         for value in query_value:
-            row = {'i': index, 'o': operation, 'v': value}
+            row = {"i": index, "o": operation, "v": value}
             formquery.append(row)
 
 
@@ -410,27 +398,26 @@ class ATBooleanCriterionConverter(CriterionConverter):
         # value = [1, True, '1', 'True']
         # value = [0, '', False, '0', 'False', None, (), [], {}, MV]
         if True in value:
-            code = 'isTrue'
+            code = "isTrue"
         elif False in value:
-            code = 'isFalse'
+            code = "isFalse"
         else:
             logger.warn(
-                'Unknown value for boolean criterion. '
-                'Falling back to True. %r',
+                "Unknown value for boolean criterion. " "Falling back to True. %r",
                 value,
             )
-            code = 'isTrue'
-        return '{0}.operation.boolean.{1}'.format(prefix, code)
+            code = "isTrue"
+        return "{0}.operation.boolean.{1}".format(prefix, code)
 
     def __call__(self, formquery, criterion, registry):
         criteria = criterion.getCriteriaItems()
         if not criteria:
             return
         for index, value in criteria:
-            if index == 'is_folderish':
-                fieldname = 'isFolderish'
-            elif index == 'is_default_page':
-                fieldname = 'isDefaultPage'
+            if index == "is_folderish":
+                fieldname = "isFolderish"
+            elif index == "is_default_page":
+                fieldname = "isDefaultPage"
             else:
                 fieldname = index
             # Check if the index is known and enabled as criterion index.
@@ -438,46 +425,44 @@ class ATBooleanCriterionConverter(CriterionConverter):
                 continue
             self.is_index_enabled(registry, fieldname)
             # Get the operation method.
-            operation = self.get_valid_operation(
-                registry, fieldname, value, criterion
-            )
+            operation = self.get_valid_operation(registry, fieldname, value, criterion)
             if not operation:
                 logger.error(INVALID_OPERATION % (operation, criterion))
                 # TODO: raise an Exception?
                 continue
             # Add a row to the form query.
-            row = {'i': index, 'o': operation}
+            row = {"i": index, "o": operation}
             formquery.append(row)
 
 
 class ATDateRangeCriterionConverter(CriterionConverter):
-    operator_code = 'date.between'
+    operator_code = "date.between"
 
     def get_query_value(self, value, index, criterion):
-        return value['query']
+        return value["query"]
 
 
 class ATPortalTypeCriterionConverter(CriterionConverter):
-    operator_code = 'selection.any'
+    operator_code = "selection.any"
 
     def get_query_value(self, value, index, criterion):
         # Special handling for portal_type=Topic.
-        if 'Topic' in value:
+        if "Topic" in value:
             value = list(value)
-            value[value.index('Topic')] = 'Collection'
+            value[value.index("Topic")] = "Collection"
             value = tuple(value)
         return value
 
 
 class ATRelativePathCriterionConverter(CriterionConverter):
     # We also have path.isWithinRelative, but its function is not defined.
-    operator_code = 'string.relativePath'
+    operator_code = "string.relativePath"
 
     def get_query_value(self, value, index, criterion):
         if not criterion.Recurse():
             logger.warn(
-                'Cannot handle non-recursive path search. '
-                'Allowing recursive search. %r',
+                "Cannot handle non-recursive path search. "
+                "Allowing recursive search. %r",
                 value,
             )
         return criterion.getRelativePath()
@@ -485,32 +470,30 @@ class ATRelativePathCriterionConverter(CriterionConverter):
 
 class ATSimpleIntCriterionConverter(CriterionConverter):
     # Also available: int.lessThan, int.largerThan.
-    operator_code = 'int.is'
+    operator_code = "int.is"
 
     def get_operation(self, value, index, criterion):
         # Get dotted operation method.
-        direction = value.get('range')
+        direction = value.get("range")
         if not direction:
-            code = 'is'
-        elif direction == 'min':
-            code = 'largerThan'
-        elif direction == 'max':
-            code = 'lessThan'
-        elif direction == 'min:max':
-            logger.warn(
-                'min:max direction not supported for integers. %r', value
-            )
+            code = "is"
+        elif direction == "min":
+            code = "largerThan"
+        elif direction == "max":
+            code = "lessThan"
+        elif direction == "min:max":
+            logger.warn("min:max direction not supported for integers. %r", value)
             return
         else:
-            logger.warn('Unknown direction for integers. %r', value)
+            logger.warn("Unknown direction for integers. %r", value)
             return
-        return '{0}.operation.int.{1}'.format(prefix, code)
+        return "{0}.operation.int.{1}".format(prefix, code)
 
     def get_query_value(self, value, index, criterion):
-        if isinstance(value['query'], tuple):
-            logger.warn('More than one integer is not supported. %r', value)
+        if isinstance(value["query"], tuple):
+            logger.warn("More than one integer is not supported. %r", value)
             return
-        return value['query']
+        return value["query"]
 
 
 class TopicMigrator:
@@ -520,13 +503,13 @@ class TopicMigrator:
     (InplaceCMFItemMigrator instead of InplaceCMFFolderMigrator).
     """
 
-    src_portal_type = 'Topic'
-    src_meta_type = 'ATTopic'
-    dst_portal_type = dst_meta_type = 'Collection'
+    src_portal_type = "Topic"
+    src_meta_type = "ATTopic"
+    dst_portal_type = dst_meta_type = "Collection"
 
     @property
     def registry(self):
-        return self.kwargs['registry']
+        return self.kwargs["registry"]
 
     def __call__(self, old_topic):
         """Store the criteria of the old Topic.
@@ -543,19 +526,19 @@ class TopicMigrator:
         self._collection_sort_reversed = None
         self._collection_sort_on = None
         self._collection_query = None
-        path = '/'.join(self.old.getPhysicalPath())
+        path = "/".join(self.old.getPhysicalPath())
         # Get the old criteria.
         # See also Products.ATContentTypes.content.topic.buildQuery
         criteria = self.old.listCriteria()
         logger.debug(
-            'Old criteria for %s: %r',
+            "Old criteria for %s: %r",
             path,
             [(crit, crit.getCriteriaItems()) for crit in criteria],
         )
         formquery = []
         for criterion in criteria:
             type_ = criterion.__class__.__name__
-            if type_ == 'ATSortCriterion':
+            if type_ == "ATSortCriterion":
                 # Sort order and direction are now stored in the Collection.
                 self._collection_sort_reversed = criterion.getReversed()
                 self._collection_sort_on = criterion.Field()
@@ -563,28 +546,28 @@ class TopicMigrator:
 
             converter = CONVERTERS.get(type_)
             if converter is None:
-                msg = 'Unsupported criterion {0}'.format(type_)
+                msg = "Unsupported criterion {0}".format(type_)
                 logger.error(msg)
                 raise ValueError(msg)
             converter(formquery, criterion, self.registry)
 
-        logger.debug('New query for %s: %r', path, formquery)
+        logger.debug("New query for %s: %r", path, formquery)
         return formquery
 
 
 CONVERTERS = {
     # Create an instance of each converter.
-    'ATBooleanCriterion': ATBooleanCriterionConverter(),
-    'ATCurrentAuthorCriterion': ATCurrentAuthorCriterionConverter(),
-    'ATDateCriteria': ATDateCriteriaConverter(),
-    'ATDateRangeCriterion': ATDateRangeCriterionConverter(),
-    'ATListCriterion': ATListCriterionConverter(),
-    'ATPathCriterion': ATPathCriterionConverter(),
-    'ATPortalTypeCriterion': ATPortalTypeCriterionConverter(),
-    'ATReferenceCriterion': ATReferenceCriterionConverter(),
-    'ATRelativePathCriterion': ATRelativePathCriterionConverter(),
-    'ATSelectionCriterion': ATSelectionCriterionConverter(),
-    'ATSimpleIntCriterion': ATSimpleIntCriterionConverter(),
-    'ATSimpleStringCriterion': ATSimpleStringCriterionConverter(),
-    'ATAllAreasCriterion': ATListCriterionConverter(),
+    "ATBooleanCriterion": ATBooleanCriterionConverter(),
+    "ATCurrentAuthorCriterion": ATCurrentAuthorCriterionConverter(),
+    "ATDateCriteria": ATDateCriteriaConverter(),
+    "ATDateRangeCriterion": ATDateRangeCriterionConverter(),
+    "ATListCriterion": ATListCriterionConverter(),
+    "ATPathCriterion": ATPathCriterionConverter(),
+    "ATPortalTypeCriterion": ATPortalTypeCriterionConverter(),
+    "ATReferenceCriterion": ATReferenceCriterionConverter(),
+    "ATRelativePathCriterion": ATRelativePathCriterionConverter(),
+    "ATSelectionCriterion": ATSelectionCriterionConverter(),
+    "ATSimpleIntCriterion": ATSimpleIntCriterionConverter(),
+    "ATSimpleStringCriterion": ATSimpleStringCriterionConverter(),
+    "ATAllAreasCriterion": ATListCriterionConverter(),
 }
